'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _reactTransitionGroup = require('react-transition-group');

var _mapToCssModules = require('../../lib/mapToCssModules');

var _mapToCssModules2 = _interopRequireDefault(_mapToCssModules);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var FirstChild = function FirstChild(_ref) {
  var children = _ref.children;
  return _react2.default.Children.toArray(children)[0] || null;
};

var propTypes = {
  children: _propTypes2.default.node,
  className: _propTypes2.default.string,
  closeClassName: _propTypes2.default.string,
  closeAriaLabel: _propTypes2.default.string,
  cssModule: _propTypes2.default.object,
  color: _propTypes2.default.string,
  isOpen: _propTypes2.default.bool,
  toggle: _propTypes2.default.func,
  tag: _propTypes2.default.oneOfType([_propTypes2.default.func, _propTypes2.default.string]),
  appearTimeout: _propTypes2.default.number,
  enterTimeout: _propTypes2.default.number,
  exitTimeout: _propTypes2.default.number
};

var defaultProps = {
  color: 'success',
  isOpen: true,
  tag: 'div',
  appearTimeout: 150,
  enterTimeout: 150,
  exitTimeout: 150,
  closeAriaLabel: 'Close'
};

var Alert = function Alert(props) {
  var className = props.className,
      closeClassName = props.closeClassName,
      closeAriaLabel = props.closeAriaLabel,
      cssModule = props.cssModule,
      Tag = props.tag,
      color = props.color,
      isOpen = props.isOpen,
      toggle = props.toggle,
      children = props.children,
      appearTimeout = props.appearTimeout,
      enterTimeout = props.enterTimeout,
      exitTimeout = props.exitTimeout,
      attributes = (0, _objectWithoutProperties3.default)(props, ['className', 'closeClassName', 'closeAriaLabel', 'cssModule', 'tag', 'color', 'isOpen', 'toggle', 'children', 'appearTimeout', 'enterTimeout', 'exitTimeout']);


  var classes = (0, _mapToCssModules2.default)((0, _classnames2.default)(className, 'alert', 'alert-' + color, { 'alert-dismissible': toggle }), cssModule);

  var closeClasses = (0, _mapToCssModules2.default)((0, _classnames2.default)('close', closeClassName), cssModule);

  var alert = _react2.default.createElement(
    Tag,
    (0, _extends3.default)({}, attributes, { className: classes, role: 'alert' }),
    toggle ? _react2.default.createElement(
      'button',
      { type: 'button', className: closeClasses, 'aria-label': closeAriaLabel, onClick: toggle },
      _react2.default.createElement(
        'span',
        { 'aria-hidden': 'true' },
        '\xD7'
      )
    ) : null,
    children
  );

  return _react2.default.createElement(
    _reactTransitionGroup.TransitionGroup,
    {
      component: FirstChild,
      enter: enterTimeout > 0,
      appear: appearTimeout > 0,
      exit: exitTimeout > 0
    },
    _react2.default.createElement(
      _reactTransitionGroup.CSSTransition,
      {
        cx: {
          appear: 'fade',
          appearActive: 'show',
          enter: 'fade',
          enterActive: 'show',
          exit: 'fade',
          exitActive: 'out'
        },
        timeout: {
          appear: appearTimeout,
          enter: enterTimeout,
          exit: exitTimeout
        }
      },
      isOpen ? alert : null
    )
  );
};

Alert.handledProps = [];
Alert.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Alert.defaultProps = defaultProps;

exports.default = Alert;