import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { TransitionGroup, CSSTransition } from 'react-transition-group';
import mapToCssModules from '../../lib/mapToCssModules';

var FirstChild = function FirstChild(_ref) {
  var children = _ref.children;
  return React.Children.toArray(children)[0] || null;
};

var propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,
  closeClassName: PropTypes.string,
  closeAriaLabel: PropTypes.string,
  cssModule: PropTypes.object,
  color: PropTypes.string,
  isOpen: PropTypes.bool,
  toggle: PropTypes.func,
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  appearTimeout: PropTypes.number,
  enterTimeout: PropTypes.number,
  exitTimeout: PropTypes.number
};

var defaultProps = {
  color: 'success',
  isOpen: true,
  tag: 'div',
  appearTimeout: 150,
  enterTimeout: 150,
  exitTimeout: 150,
  closeAriaLabel: 'Close'
};

var Alert = function Alert(props) {
  var className = props.className,
      closeClassName = props.closeClassName,
      closeAriaLabel = props.closeAriaLabel,
      cssModule = props.cssModule,
      Tag = props.tag,
      color = props.color,
      isOpen = props.isOpen,
      toggle = props.toggle,
      children = props.children,
      appearTimeout = props.appearTimeout,
      enterTimeout = props.enterTimeout,
      exitTimeout = props.exitTimeout,
      attributes = _objectWithoutProperties(props, ['className', 'closeClassName', 'closeAriaLabel', 'cssModule', 'tag', 'color', 'isOpen', 'toggle', 'children', 'appearTimeout', 'enterTimeout', 'exitTimeout']);

  var classes = mapToCssModules(cx(className, 'alert', 'alert-' + color, { 'alert-dismissible': toggle }), cssModule);

  var closeClasses = mapToCssModules(cx('close', closeClassName), cssModule);

  var alert = React.createElement(
    Tag,
    _extends({}, attributes, { className: classes, role: 'alert' }),
    toggle ? React.createElement(
      'button',
      { type: 'button', className: closeClasses, 'aria-label': closeAriaLabel, onClick: toggle },
      React.createElement(
        'span',
        { 'aria-hidden': 'true' },
        '\xD7'
      )
    ) : null,
    children
  );

  return React.createElement(
    TransitionGroup,
    {
      component: FirstChild,
      enter: enterTimeout > 0,
      appear: appearTimeout > 0,
      exit: exitTimeout > 0
    },
    React.createElement(
      CSSTransition,
      {
        cx: {
          appear: 'fade',
          appearActive: 'show',
          enter: 'fade',
          enterActive: 'show',
          exit: 'fade',
          exitActive: 'out'
        },
        timeout: {
          appear: appearTimeout,
          enter: enterTimeout,
          exit: exitTimeout
        }
      },
      isOpen ? alert : null
    )
  );
};

Alert.handledProps = [];
Alert.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
Alert.defaultProps = defaultProps;

export default Alert;