import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { TransitionGroup } from 'react-transition-group';
import { mapToCssModules } from '../../lib/';

var Carousel = function (_React$Component) {
  _inherits(Carousel, _React$Component);

  function Carousel(props) {
    _classCallCheck(this, Carousel);

    var _this = _possibleConstructorReturn(this, (Carousel.__proto__ || Object.getPrototypeOf(Carousel)).call(this, props));

    _this.handleKeyPress = _this.handleKeyPress.bind(_this);
    _this.state = { direction: 'right' };
    return _this;
  }

  _createClass(Carousel, [{
    key: 'getChildContext',
    value: function getChildContext() {
      return { direction: this.state.direction };
    }
  }, {
    key: 'componentDidMount',
    value: function componentDidMount() {
      var _this2 = this;

      // Set up the cycle
      if (this.props.interval) {
        this.cycleInterval = setInterval(function () {
          if (!_this2.props.paused) {
            _this2.props.next();
          }
        }, parseInt(this.props.interval, 10));
      }

      if (this.props.keyboard) {
        document.addEventListener('keyup', this.handleKeyPress);
      }
    }
  }, {
    key: 'componentWillReceiveProps',
    value: function componentWillReceiveProps(nextProps) {
      // Calculate the direction to turn
      if (this.props.activeIndex + 1 === nextProps.activeIndex) {
        this.setState({ direction: 'right' });
      } else if (this.props.activeIndex - 1 === nextProps.activeIndex) {
        this.setState({ direction: 'left' });
      } else if (this.props.activeIndex > nextProps.activeIndex) {
        this.setState({ direction: 'right' });
      } else {
        this.setState({ direction: 'left' });
      }
    }
  }, {
    key: 'componentWillUnmount',
    value: function componentWillUnmount() {
      clearInterval(this.cycleInterval);
      document.removeEventListener('key', this.handleKeyPress);
    }
  }, {
    key: 'handleKeyPress',
    value: function handleKeyPress(evt) {
      if (this.props.keyboard && evt.keyCode === 37) {
        this.props.previous();
      } else if (this.props.keyboard && evt.keyCode === 39) {
        this.props.next();
      }
    }
  }, {
    key: 'render',
    value: function render() {
      var _this3 = this;

      var _props = this.props,
          children = _props.children,
          cssModule = _props.cssModule,
          activeIndex = _props.activeIndex,
          hoverStart = _props.hoverStart,
          hoverEnd = _props.hoverEnd;

      var outerClasses = mapToCssModules(cx('carousel', 'slide'), cssModule);

      var innerClasses = mapToCssModules(cx('carousel-inner'), cssModule);

      var slidesOnly = children.every(function (child) {
        return child.type && child.type.name === 'CarouselItem';
      });

      // Rendering only slides
      if (slidesOnly) {
        return React.createElement(
          'div',
          { className: outerClasses, onMouseEnter: hoverStart, onMouseLeave: hoverEnd },
          React.createElement(
            TransitionGroup,
            { component: 'div', role: 'listbox', className: innerClasses },
            children[activeIndex]
          )
        );
      }

      // Rendering slides and controls
      if (children[0] instanceof Array) {
        var _carouselItems = children[0];
        var _controlLeft = children[1];
        var _controlRight = children[2];

        return React.createElement(
          'div',
          { className: outerClasses, onMouseEnter: hoverStart, onMouseLeave: hoverEnd },
          React.createElement(
            TransitionGroup,
            { component: 'div', role: 'listbox', className: innerClasses },
            _carouselItems[activeIndex]
          ),
          _controlLeft,
          _controlRight
        );
      }

      // Rendering indicators, slides and controls
      var indicators = children[0];
      var carouselItems = children[1];
      var controlLeft = children[2];
      var controlRight = children[3];

      return React.createElement(
        'div',
        {
          ref: function ref(carousel) {
            _this3.carousel = carousel;
          },
          className: outerClasses,
          onMouseEnter: hoverStart,
          onMouseLeave: hoverEnd
        },
        indicators,
        React.createElement(
          TransitionGroup,
          { component: 'div', role: 'listbox', className: innerClasses },
          carouselItems[activeIndex]
        ),
        controlLeft,
        controlRight
      );
    }
  }]);

  return Carousel;
}(React.Component);

Carousel.handledProps = ['activeIndex', 'children', 'cssModule', 'hover', 'hoverEnd', 'hoverStart', 'interval', 'keyboard', 'next', 'paused', 'previous'];


Carousel.propTypes = process.env.NODE_ENV !== "production" ? {
  paused: PropTypes.bool,
  next: PropTypes.func.isRequired,
  previous: PropTypes.func.isRequired,
  keyboard: PropTypes.bool,
  cssModule: PropTypes.object,
  activeIndex: PropTypes.number,
  interval: PropTypes.oneOfType([PropTypes.number, PropTypes.string, PropTypes.bool]),
  children: PropTypes.array,
  hoverStart: PropTypes.func,
  hoverEnd: PropTypes.func,
  hover: PropTypes.bool
} : {};

Carousel.defaultProps = {
  interval: 5000,
  hover: false,
  paused: false,
  keyboard: true
};

Carousel.childContextTypes = {
  direction: PropTypes.string
};

export default Carousel;