/* eslint-disable jsx-a11y/interactive-supports-focus */
import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { mapToCssModules } from '../../lib/';

var CarouselControl = function CarouselControl(props) {
  var direction = props.direction,
      onClickHandler = props.onClickHandler,
      cssModule = props.cssModule,
      directionText = props.directionText;


  var anchorClasses = mapToCssModules(cx('carousel-control-' + direction), cssModule);

  var iconClasses = mapToCssModules(cx('carousel-control-' + direction + '-icon'), cssModule);

  var screenReaderClasses = mapToCssModules(cx('sr-only'), cssModule);

  return React.createElement(
    'a',
    {
      className: anchorClasses,
      role: 'button',
      onClick: function onClick(e) {
        e.preventDefault();
        onClickHandler();
      }
    },
    React.createElement('span', { className: iconClasses, 'aria-hidden': 'true' }),
    React.createElement(
      'span',
      { className: screenReaderClasses },
      directionText || direction
    )
  );
};

CarouselControl.handledProps = ['cssModule', 'direction', 'directionText', 'onClickHandler'];
CarouselControl.propTypes = process.env.NODE_ENV !== "production" ? {
  direction: PropTypes.oneOf(['prev', 'next']).isRequired,
  onClickHandler: PropTypes.func.isRequired,
  cssModule: PropTypes.object,
  directionText: PropTypes.string
} : {};

export default CarouselControl;