import React from 'react'
import PropTypes from 'prop-types'
import cx from 'classnames'
import { mapToCssModules } from '../../lib/'

const propTypes = {
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  wrapTag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  toggle: PropTypes.func,
  className: PropTypes.string,
  cssModule: PropTypes.object,
  children: PropTypes.node,
  closeAriaLabel: PropTypes.string,
}

const defaultProps = {
  tag: 'h4',
  wrapTag: 'div',
  closeAriaLabel: 'Close',
}

const ModalHeader = (props) => {
  let closeButton
  const {
    className,
    cssModule,
    children,
    toggle,
    tag: Tag,
    wrapTag: WrapTag,
    closeAriaLabel,
    ...attributes } = props

  const classes = mapToCssModules(cx(
    className,
    'modal-header',
  ), cssModule)

  if (toggle) {
    closeButton = (
      <button type='button' onClick={toggle} className='close' aria-label={closeAriaLabel}>
        <span aria-hidden='true'>{String.fromCharCode(215)}</span>
      </button>
    )
  }

  return (
    <WrapTag {...attributes} className={classes}>
      <Tag className={mapToCssModules('modal-title', cssModule)}>
        {children}
      </Tag>
      {closeButton}
    </WrapTag>
  )
}

ModalHeader.propTypes = propTypes
ModalHeader.defaultProps = defaultProps

export default ModalHeader
